@@ -50,21 +50,21 @@ require_once 'Net/Socket.php';
  *
  * @const NET_SIEVE_STATE_DISCONNECTED
  */
-define('NET_SIEVE_STATE_DISCONNECTED', 1, true);
+define('NET_SIEVE_STATE_DISCONNECTED', 1);
 
 /**
  * Authorisation state
  *
  * @const NET_SIEVE_STATE_AUTHORISATION
  */
-define('NET_SIEVE_STATE_AUTHORISATION', 2, true);
+define('NET_SIEVE_STATE_AUTHORISATION', 2);
 
 /**
  * Transaction state
  *
  * @const NET_SIEVE_STATE_TRANSACTION
  */
-define('NET_SIEVE_STATE_TRANSACTION', 3, true);
+define('NET_SIEVE_STATE_TRANSACTION', 3);
 
 
 /**
@@ -80,7 +80,7 @@ define('NET_SIEVE_STATE_TRANSACTION', 3, true);
  * @copyright 2002-2003 Richard Heyes
  * @copyright 2006-2008 Anish Mistry
  * @license   http://www.opensource.org/licenses/bsd-license.php BSD
- * @version   Release: 1.4.3
+ * @version   Release: 1.4.4
  * @link      http://pear.php.net/package/Net_Sieve
  * @link      http://tools.ietf.org/html/rfc5228 RFC 5228 (Sieve: An Email
  *            Filtering Language)
